=== modified file 'ChangeLog'
--- ChangeLog	2006-08-02 23:13:59 +0000
+++ ChangeLog	2006-08-03 10:14:44 +0000
@@ -1,5 +1,7 @@
 2006-08-03  Szilveszter Farkas <Szilveszter.Farkas@gmail.com>
 
+    * olive/frontend/gtk/commit.py: change TextView font to Monospace
+    * olive/frontend/gtk/diff.py: implemented diff window
     * olive.glade: added icons to windows and the about box, and the skeleton
       of the diff window was designed
 

=== modified file 'olive.glade'
--- olive.glade	2006-08-02 23:13:59 +0000
+++ olive.glade	2006-08-03 10:14:44 +0000
@@ -2096,7 +2096,8 @@
 </widget>
 
 <widget class="GtkWindow" id="window_diff">
-  <property name="width_request">500</property>
+  <property name="width_request">600</property>
+  <property name="height_request">400</property>
   <property name="visible">True</property>
   <property name="title" translatable="yes">Olive - Diff</property>
   <property name="type">GTK_WINDOW_TOPLEVEL</property>
@@ -2139,13 +2140,14 @@
 		<widget class="GtkTreeView" id="treeview_diff_files">
 		  <property name="visible">True</property>
 		  <property name="can_focus">True</property>
-		  <property name="headers_visible">True</property>
+		  <property name="headers_visible">False</property>
 		  <property name="rules_hint">False</property>
 		  <property name="reorderable">False</property>
 		  <property name="enable_search">True</property>
 		  <property name="fixed_height_mode">False</property>
 		  <property name="hover_selection">False</property>
 		  <property name="hover_expand">False</property>
+		  <signal name="cursor_changed" handler="on_treeview_diff_files_cursor_changed" last_modification_time="Thu, 03 Aug 2006 09:02:37 GMT"/>
 		</widget>
 	      </child>
 	    </widget>

=== modified file 'olive/frontend/gtk/commit.py'
--- olive/frontend/gtk/commit.py	2006-08-01 16:16:31 +0000
+++ olive/frontend/gtk/commit.py	2006-08-03 10:14:44 +0000
@@ -25,10 +25,16 @@
     import gtk
     import gtk.glade
     import gobject
+    import pango
 except:
     sys.exit(1)
 
-from bzrlib.delta import compare_trees
+import bzrlib
+
+if bzrlib.version_info[1] < 9:
+    # function deprecated after 0.9
+    from bzrlib.delta import compare_trees
+
 import bzrlib.errors as errors
 from bzrlib.workingtree import WorkingTree
 
@@ -38,8 +44,6 @@
     """ Display Commit dialog and perform the needed actions. """
     def __init__(self, gladefile, comm):
         """ Initialize the Commit dialog. """
-        import bzrlib
-        
         self.gladefile = gladefile
         self.glade = gtk.glade.XML(self.gladefile, 'window_commit')
         
@@ -86,6 +90,7 @@
         
         # Some additional widgets
         self.checkbutton_local = self.glade.get_widget('checkbutton_commit_local')
+        self.textview = self.glade.get_widget('textview_commit')
     
     def display(self):
         """ Display the Push dialog. """
@@ -97,6 +102,7 @@
                 # we have a checkout, so the local commit checkbox must appear
                 self.checkbutton_local.show()
             
+            self.textview.modify_font(pango.FontDescription("Monospace"))
             self.window.show()
             
     
@@ -145,8 +151,7 @@
         return
     
     def commit(self, widget):
-        textview = self.glade.get_widget('textview_commit')
-        textbuffer = textview.get_buffer()
+        textbuffer = self.textview.get_buffer()
         start, end = textbuffer.get_bounds()
         message = textbuffer.get_text(start, end)
         

=== added file 'olive/frontend/gtk/diff.py'
--- olive/frontend/gtk/diff.py	1970-01-01 00:00:00 +0000
+++ olive/frontend/gtk/diff.py	2006-08-03 10:14:44 +0000
@@ -0,0 +1,187 @@
+# Copyright (C) 2006 by Szilveszter Farkas (Phanatic) <szilveszter.farkas@gmail.com>
+#
+# Some parts of the code:
+# Copyright (C) 2005 by Canonical Ltd.
+# Author: Scott James Remnant <scott@ubuntu.com>
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+import sys
+
+from cStringIO import StringIO
+
+try:
+    import pygtk
+    pygtk.require("2.0")
+except:
+    pass
+try:
+    import gtk
+    import gtk.glade
+    import gobject
+    import pango
+except:
+    sys.exit(1)
+
+try:
+    import gtksourceview
+    have_gtksourceview = True
+except ImportError:
+    have_gtksourceview = False
+
+import bzrlib
+
+if bzrlib.version_info[1] < 9:
+    # function deprecated after 0.9
+    from bzrlib.delta import compare_trees
+
+from bzrlib.diff import show_diff_trees
+import bzrlib.errors as errors
+from bzrlib.workingtree import WorkingTree
+
+from dialog import OliveDialog
+
+class OliveDiff:
+    """ Display Diff window and perform the needed actions. """
+    def __init__(self, gladefile, comm):
+        """ Initialize the Diff window. """
+        self.gladefile = gladefile
+        self.glade = gtk.glade.XML(self.gladefile, 'window_diff')
+        
+        self.comm = comm
+        
+        self.dialog = OliveDialog(self.gladefile)
+        
+        # Check if current location is a branch
+        try:
+            (self.wt, path) = WorkingTree.open_containing(self.comm.get_path())
+            branch = self.wt.branch
+        except errors.NotBranchError:
+            self.notbranch = True
+            return
+        except:
+            raise
+
+        file_id = self.wt.path2id(path)
+
+        self.notbranch = False
+        if file_id is None:
+            self.notbranch = True
+            return
+        
+        # Set the old working tree
+        self.old_tree = self.wt.branch.repository.revision_tree(self.wt.branch.last_revision())
+        
+        # Get the Diff window widget
+        self.window = self.glade.get_widget('window_diff')
+        
+        # Dictionary for signal_autoconnect
+        dic = { "on_button_diff_close_clicked": self.close,
+                "on_treeview_diff_files_cursor_changed": self.cursor_changed }
+        
+        # Connect the signals to the handlers
+        self.glade.signal_autoconnect(dic)
+        
+        # Create the file list
+        self._create_file_view()
+        
+        # Generate initial diff
+        self._init_diff()
+    
+    def display(self):
+        """ Display the Diff window. """
+        if self.notbranch:
+            self.dialog.error_dialog('Directory is not a branch.')
+        else:
+            self.window.show_all()
+    
+    def _create_file_view(self):
+        """ Create the list of files. """
+        self.model = gtk.TreeStore(str, str)
+        self.treeview = self.glade.get_widget('treeview_diff_files')
+        self.treeview.set_model(self.model)
+        
+        cell = gtk.CellRendererText()
+        cell.set_property("width-chars", 20)
+        column = gtk.TreeViewColumn()
+        column.pack_start(cell, expand=True)
+        column.add_attribute(cell, "text", 0)
+        self.treeview.append_column(column)
+        
+        if have_gtksourceview:
+            self.buffer = gtksourceview.SourceBuffer()
+            slm = gtksourceview.SourceLanguagesManager()
+            gsl = slm.get_language_from_mime_type("text/x-patch")
+            self.buffer.set_language(gsl)
+            self.buffer.set_highlight(True)
+
+            sourceview = gtksourceview.SourceView(self.buffer)
+        else:
+            self.buffer = gtk.TextBuffer()
+            sourceview = gtk.TextView(self.buffer)
+
+        sourceview.set_editable(False)
+        sourceview.modify_font(pango.FontDescription("Monospace"))
+        scrollwin_diff = self.glade.get_widget('scrolledwindow_diff_diff')
+        scrollwin_diff.add(sourceview)
+    
+    def _init_diff(self):
+        """ Generate initial diff. """
+        self.model.clear()
+        if bzrlib.version_info[1] < 9:
+            delta = compare_trees(self.old_tree, self.wt)
+        else:
+            delta = self.wt.changes_from(self.old_tree)
+
+        self.model.append(None, [ "Complete Diff", "" ])
+
+        if len(delta.added):
+            titer = self.model.append(None, [ "Added", None ])
+            for path, id, kind in delta.added:
+                self.model.append(titer, [ path, path ])
+
+        if len(delta.removed):
+            titer = self.model.append(None, [ "Removed", None ])
+            for path, id, kind in delta.removed:
+                self.model.append(titer, [ path, path ])
+
+        if len(delta.renamed):
+            titer = self.model.append(None, [ "Renamed", None ])
+            for oldpath, newpath, id, kind, text_modified, meta_modified \
+                    in delta.renamed:
+                self.model.append(titer, [ oldpath, newpath ])
+
+        if len(delta.modified):
+            titer = self.model.append(None, [ "Modified", None ])
+            for path, id, kind, text_modified, meta_modified in delta.modified:
+                self.model.append(titer, [ path, path ])
+
+        self.treeview.expand_all()
+    
+    def cursor_changed(self, *args):
+        """ Callback when the TreeView cursor changes. """
+        (path, col) = self.treeview.get_cursor()
+        specific_files = [ self.model[path][1] ]
+        if specific_files == [ None ]:
+            return
+        elif specific_files == [ "" ]:
+            specific_files = []
+
+        s = StringIO()
+        show_diff_trees(self.old_tree, self.wt, s, specific_files)
+        self.buffer.set_text(s.getvalue())
+    
+    def close(self, widget=None):
+        self.window.destroy()

=== added file 'olive/frontend/gtk/menu.py'
--- olive/frontend/gtk/menu.py	1970-01-01 00:00:00 +0000
+++ olive/frontend/gtk/menu.py	2006-08-03 10:14:44 +0000
@@ -0,0 +1,137 @@
+# Copyright (C) 2006 by Szilveszter Farkas (Phanatic) <szilveszter.farkas@gmail.com>
+
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+import os.path
+import sys
+
+try:
+    import pygtk
+    pygtk.require("2.0")
+except:
+    pass
+try:
+    import gtk
+    import gtk.glade
+except:
+    sys.exit(1)
+
+import olive.backend.fileops as fileops
+import olive.backend.errors as errors
+
+from commit import OliveCommit
+from diff import OliveDiff
+
+class OliveMenu:
+    """ This class is responsible for building the context menus. """
+    def __init__(self, gladefile, comm, dialog):
+        # Load the UI file
+        self.uifile = "/usr/share/olive/cmenu.ui"
+        if not os.path.exists(self.uifile):
+            # Load from current directory if not installed
+            self.uifile = "cmenu.ui"
+        
+        self.gladefile = gladefile
+        self.comm = comm
+        self.dialog = dialog
+        
+        self.ui_right = gtk.UIManager()
+        
+        self.actiongroup_right = gtk.ActionGroup('context_right')
+        self.actiongroup_right.add_actions([('add', gtk.STOCK_ADD,
+                                             'Add', None,
+                                             'Add the selected file',
+                                             self.add_file),
+                                            ('remove', gtk.STOCK_REMOVE,
+                                             'Remove', None,
+                                             'Remove the selected file',
+                                             self.remove_file),
+                                            ('commit', gtk.STOCK_REDO,
+                                             'Commit', None,
+                                             'Commit the changes',
+                                             self.commit),
+                                            ('diff', None,
+                                             'Diff', None,
+                                             'Show the diff of the file',
+                                             self.diff),
+                                            ('log', None,
+                                             'Log', None,
+                                             'Show the log of the file',
+                                             self.log)])
+        
+        self.ui_right.insert_action_group(self.actiongroup_right, 0)
+        self.ui_right.add_ui_from_file(self.uifile)
+        
+        self.cmenu_right = self.ui_right.get_widget('/context_right')
+
+    def right_context_menu(self):
+        return self.cmenu_right
+    
+    def add_file(self, action):
+        """ Right context menu -> Add """
+        # Add only the selected file
+        directory = self.comm.get_path()
+        filename = self.comm.get_selected_right()
+            
+        if filename is None:
+            self.dialog.error_dialog('No file was selected.')
+            return
+        
+        try:
+            fileops.add([directory + '/' + filename])
+        except errors.NotBranchError:
+            self.dialog.error_dialog('The directory is not a branch.')
+            return
+        except:
+            raise
+        
+        self.comm.refresh_right()
+    
+    def remove_file(self, action):
+        """ Right context menu -> Remove """
+        # Remove only the selected file
+        directory = self.comm.get_path()
+        filename = self.comm.get_selected_right()
+        
+        if filename is None:
+            self.dialog.error_dialog('No file was selected.')
+            return
+        
+        try:
+            fileops.remove([directory + '/' + filename])
+        except errors.NotBranchError:
+            self.dialog.error_dialog('The directory is not a branch.')
+            return
+        except errors.NotVersionedError:
+            self.dialog.error_dialog('Selected file is not versioned.')
+            return
+        except:
+            raise
+        
+        self.comm.refresh_right()
+
+    def commit(self, action):
+        """ Right context menu -> Commit """
+        commit = OliveCommit(self.gladefile, self.comm)
+        commit.display()
+    
+    def diff(self, action):
+        """ Right context menu -> Diff """
+        diff = OliveDiff(self.gladefile, self.comm)
+        diff.display()
+    
+    def log(self, action):
+        """ Right context menu -> Log """
+        self.dialog.error_dialog('This feature is not yet implemented.')

